@@ -18,12 +18,12 @@ extern "C" {
 
 /* Version numbers */
 #define BLOSC_VERSION_MAJOR    1    /* for major interface/format changes  */
-#define BLOSC_VERSION_MINOR    14   /* for minor interface/format changes  */
-#define BLOSC_VERSION_RELEASE  0    /* for tweaks, bug-fixes, or development */
+#define BLOSC_VERSION_MINOR    15   /* for minor interface/format changes  */
+#define BLOSC_VERSION_RELEASE  1    /* for tweaks, bug-fixes, or development */
 
-#define BLOSC_VERSION_STRING   "1.14.0"  /* string version.  Sync with above! */
+#define BLOSC_VERSION_STRING   "1.15.1.dev"  /* string version.  Sync with above! */
 #define BLOSC_VERSION_REVISION "$Rev$"   /* revision version */
-#define BLOSC_VERSION_DATE     "$Date:: 2018-02-23 #$"    /* date version */
+#define BLOSC_VERSION_DATE     "$Date:: 2018-11-30 #$"    /* date version */
 
 #define BLOSCLZ_VERSION_STRING "1.1.0"   /* the internal compressor version */
 
@@ -142,24 +142,24 @@ BLOSC_EXPORT void blosc_destroy(void);
   `clevel` is the desired compression level and must be a number
   between 0 (no compression) and 9 (maximum compression).
 
-  `doshuffle` specifies whether the shuffle compression preconditioner
+  `doshuffle` specifies whether the shuffle compression filters
   should be applied or not.  BLOSC_NOSHUFFLE means not applying it,
   BLOSC_SHUFFLE means applying it at a byte level and BLOSC_BITSHUFFLE
   at a bit level (slower but may achieve better entropy alignment).
 
   `typesize` is the number of bytes for the atomic type in binary
-  `src` buffer.  This is mainly useful for the shuffle preconditioner.
-  For implementation reasons, only a 1 < typesize < 256 will allow the
-  shuffle filter to work.  When typesize is not in this range, shuffle
+  `src` buffer.  This is mainly useful for the shuffle filters.
+  For implementation reasons, only a 1 < `typesize` < 256 will allow the
+  shuffle filter to work.  When `typesize` is not in this range, shuffle
   will be silently disabled.
 
   The `dest` buffer must have at least the size of `destsize`.  Blosc
   guarantees that if you set `destsize` to, at least,
-  (`nbytes`+BLOSC_MAX_OVERHEAD), the compression will always succeed.
+  (`nbytes` + BLOSC_MAX_OVERHEAD), the compression will always succeed.
   The `src` buffer and the `dest` buffer can not overlap.
 
   Compression is memory safe and guaranteed not to write the `dest`
-  buffer more than what is specified in `destsize`.
+  buffer beyond what is specified in `destsize`.
 
   If `src` buffer cannot be compressed into `destsize`, the return
   value is zero and you should discard the contents of the `dest`
@@ -247,7 +247,7 @@ BLOSC_EXPORT int blosc_compress_ctx(int clevel, int doshuffle, size_t typesize,
   The `src` buffer and the `dest` buffer can not overlap.
 
   Decompression is memory safe and guaranteed not to write the `dest`
-  buffer more than what is specified in `destsize`.
+  buffer beyond what is specified in `destsize`.
 
   If an error occurs, e.g. the compressed data is corrupted or the
   output buffer is not large enough, then 0 (zero) or a negative value
@@ -321,7 +321,7 @@ BLOSC_EXPORT int blosc_set_nthreads(int nthreads);
 
 
 /**
-  Returns the current compressor that is used for compression.
+  Returns the current compressor that is being used for compression.
   */
 BLOSC_EXPORT const char* blosc_get_compressor(void);
 
@@ -329,7 +329,7 @@ BLOSC_EXPORT const char* blosc_get_compressor(void);
 /**
   Select the compressor to be used.  The supported ones are "blosclz",
   "lz4", "lz4hc", "snappy", "zlib" and "ztsd".  If this function is not
-  called, then "blosclz" will be used.
+  called, then "blosclz" will be used by default.
 
   In case the compressor is not recognized, or there is not support
   for it in this build, it returns a -1.  Else it returns the code for
@@ -371,7 +371,7 @@ BLOSC_EXPORT int blosc_compname_to_compcode(const char *compname);
 BLOSC_EXPORT const char* blosc_list_compressors(void);
 
 /**
-  Return the version of blosc in string format.
+  Return the version of the C-Blosc library in string format.
 
   Useful for dynamic libraries.
 */
@@ -381,13 +381,12 @@ BLOSC_EXPORT const char* blosc_get_version_string(void);
 /**
   Get info from compression libraries included in the current build.
   In `compname` you pass the compressor name that you want info from.
-  In `complib` and `version` you get the compression library name and
-  version (if available) as output.
 
   In `complib` and `version` you get a pointer to the compressor
   library name and the version in string format respectively.  After
   using the name and version, you should free() them so as to avoid
-  leaks.
+  leaks.  If any of `complib` and `version` are NULL, they will not be
+  assigned to anything, and the user should not need to free them.
 
   If the compressor is supported, it returns the code for the library
   (>=0).  If it is not supported, this function returns -1.
@@ -421,7 +420,7 @@ BLOSC_EXPORT void blosc_cbuffer_sizes(const void *cbuffer, size_t *nbytes,
 
 
 /**
-  Return information about a compressed buffer, namely the type size
+  Return meta-information about a compressed buffer, namely the type size
   (`typesize`), as well as some internal `flags`.
 
   The `flags` is a set of bits, where the used ones are:
@@ -434,22 +433,25 @@ BLOSC_EXPORT void blosc_cbuffer_sizes(const void *cbuffer, size_t *nbytes,
   (e.g. ``flags & BLOSC_DOSHUFFLE`` says whether the buffer is
   byte-shuffled or not).
 
+  You only need to pass the first BLOSC_MIN_HEADER_LENGTH bytes of a
+  compressed buffer for this call to work.
+
   If the format is not supported by the library, all output arguments will be
   filled with zeros.
   */
 BLOSC_EXPORT void blosc_cbuffer_metainfo(const void *cbuffer, size_t *typesize,
-					 int *flags);
+					                               int *flags);
 
 
 /**
   Return information about a compressed buffer, namely the internal
   Blosc format version (`version`) and the format for the internal
-  Lempel-Ziv compressor used (`versionlz`).
+  compressor used (`compversion`).
 
   This function should always succeed.
   */
 BLOSC_EXPORT void blosc_cbuffer_versions(const void *cbuffer, int *version,
-                                             int *versionlz);
+                                         int *compversion);
 
 
 /**
@@ -467,8 +469,10 @@ BLOSC_EXPORT const char *blosc_cbuffer_complib(const void *cbuffer);
 
 *********************************************************************/
 
-/* Get the internal blocksize to be used during compression.  0 means
-   that an automatic blocksize is computed internally. */
+/**
+  Get the internal blocksize to be used during compression.  0 means
+  that an automatic blocksize is computed internally (the default).
+  */
 BLOSC_EXPORT int blosc_get_blocksize(void);
 
 /**
@@ -483,19 +487,20 @@ BLOSC_EXPORT void blosc_set_blocksize(size_t blocksize);
 /**
   Set the split mode.
 
- This function can take the next values:
- *  BLOSC_FORWARD_COMPAT_SPLIT
- *  BLOSC_AUTO_SPLIT
- *  BLOSC_NEVER_SPLIT
- *  BLOSC_ALWAYS_SPLIT
+  This function can take the next values:
+  *  BLOSC_FORWARD_COMPAT_SPLIT
+  *  BLOSC_AUTO_SPLIT
+  *  BLOSC_NEVER_SPLIT
+  *  BLOSC_ALWAYS_SPLIT
 
- FORWARD_COMPAT offers reasonably forward compatibility, AUTO is for nearly optimal results (based
- on heuristics), NEVER and ALWAYS are for the user experimenting when trying to get best
- compression ratios and/or speed.
+  BLOSC_FORWARD_COMPAT offers reasonably forward compatibility,
+  BLOSC_AUTO_SPLIT is for nearly optimal results (based on heuristics),
+  BLOSC_NEVER_SPLIT and BLOSC_ALWAYS_SPLIT are for the user experimenting
+  when trying to get best compression ratios and/or speed.
 
- If not called, the default mode is BLOSC_FORWARD_COMPAT_SPLIT.
+  If not called, the default mode is BLOSC_FORWARD_COMPAT_SPLIT.
 
- This function should always succeed.
+  This function should always succeed.
  */
 BLOSC_EXPORT void blosc_set_splitmode(int splitmode);
 
